import * as i0 from '@angular/core';
import { InjectionToken, inject, Injectable, Optional, Inject, Component, input, NgModule, SkipSelf } from '@angular/core';
import { JwtHelperService } from '@auth0/angular-jwt';
import { SharePointService } from '@cleavelandprice/ngx-lib/sharepoint';
import { AuthenticationTokenService } from '@cleavelandprice/ngx-lib/authentication/token';
import * as i1 from '@angular/forms';
import { FormGroup, FormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogRef, MatDialogActions, MatDialogContent, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { MatButton, MatButtonModule } from '@angular/material/button';
import { MatFormField, MatFormFieldModule } from '@angular/material/form-field';
import { MatIcon, MatIconModule } from '@angular/material/icon';
import { MatInput, MatInputModule } from '@angular/material/input';
import { MatProgressSpinner, MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatSlideToggle, MatSlideToggleModule } from '@angular/material/slide-toggle';
import { ConfirmationComponent } from '@cleavelandprice/ngx-lib/dialog';
import { CommonModule } from '@angular/common';

const MatAuthenticationServiceOptionsToken = new InjectionToken('');

class MatAuthenticationService extends AuthenticationTokenService {
    #sharePointService = inject(SharePointService);
    //#region Lifecycle
    constructor(constructorOptions) {
        super({ ...constructorOptions, deferTokenValidation: true });
        // When super() was called, the parent class defined the 'options' object with all of the other properties
        this.options = { ...this.options, ...constructorOptions };
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    validateUser(token) {
        const jwtHelper = new JwtHelperService();
        const decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        this.storage.setItem(this.options.tokenName, token);
        this.#getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    #getPhoto() {
        this.#sharePointService.getPhotos()
            .subscribe(photos => {
            // The user may have been logged out by the time the photos came back
            if (!this.authenticatedUser?.employeeNumber) {
                return;
            }
            const photo = photos.find(pic => pic.employeeNumber === +this.authenticatedUser.employeeNumber);
            if (photo) {
                this.authenticatedUser.photoUrl = photo.encodedAbsUrl;
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationService, deps: [{ token: MatAuthenticationServiceOptionsToken, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [MatAuthenticationServiceOptionsToken]
                }] }] });

class LoginFormComponent {
    constructor() {
        this.#data = inject(MAT_DIALOG_DATA);
        this.services = {
            dialogRef: inject((MatDialogRef)),
            authentication: inject(MatAuthenticationService)
        };
        this.form = new FormGroup({
            username: new FormControl(null, [Validators.required]),
            password: new FormControl(null, [Validators.required]),
            adminGroup: new FormControl(),
            additionalInfo: new FormControl()
        });
    }
    #data;
    ngOnInit() {
        this.form.get('adminGroup')?.setValue(this.#data.adminGroup);
        this.form.get('additionalInfo')?.setValue(this.#data.additionalInfo);
        this.authenticatedChangedSubscription = this.services.authentication.authenticatedChanged
            .subscribe(this.#authChangedHandler.bind(this));
        this.authenticationErrorSubscription = this.services.authentication.authenticationError
            .subscribe(this.#errorHandler.bind(this));
    }
    ngOnDestroy() {
        this.authenticationErrorSubscription.unsubscribe();
        this.authenticatedChangedSubscription.unsubscribe();
    }
    authenticate() {
        this.errorMessage = undefined;
        const { username, password, adminGroup, additionalInfo } = this.form.value;
        this.services.authentication.login(username, password, adminGroup, additionalInfo);
    }
    #authChangedHandler(authenticated) {
        if (authenticated) {
            this.services.dialogRef.close();
        }
    }
    #errorHandler(err) {
        console.log('Authentication error', err);
        this.errorMessage = `${err.name}: ${err.statusText}`;
    }
    changeTokenStorageMode(checked) {
        const keyName = 'storeTokenInSession';
        if (checked) {
            if (localStorage.getItem(keyName)) {
                localStorage.removeItem(keyName);
            }
        }
        else {
            localStorage.setItem(keyName, 'true');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: LoginFormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.5", type: LoginFormComponent, isStandalone: true, selector: "ng-component", ngImport: i0, template: "<h2 mat-dialog-title>\n  @if (services.authentication.authenticating) {\n    <span>Authenticating...</span>\n  } @else {\n    <span>Login</span>\n  }\n</h2>\n\n<mat-dialog-content>\n  @if (services.authentication.authenticating) {\n    <div id=\"spinner\">\n      <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"/>\n    </div>\n  } @else if (errorMessage) {\n    <div id=\"error\">\n      {{ errorMessage }}\n    </div>\n  } @else {\n    <form [formGroup]=\"form\">\n      <mat-form-field>\n        <input matInput formControlName=\"username\" placeholder=\"Username\" (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n      <mat-form-field>\n        <input matInput formControlName=\"password\" type=\"password\" placeholder=\"Password\" (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n      @if (services.authentication.options.showRememberMeOption) {\n        <mat-slide-toggle [checked]=\"!services.authentication.useSessionStorage\" (change)=\"changeTokenStorageMode($event.checked)\">\n          Remember me next time\n        </mat-slide-toggle>\n      }\n    </form>\n  }\n</mat-dialog-content>\n\n@if (!services.authentication.authenticating) {\n  <mat-dialog-actions>\n    <button mat-raised-button color=\"primary\" (click)=\"authenticate()\"\n      [disabled]=\"form.invalid\">\n      <mat-icon fontIcon=\"done\"/>\n      <span>OK</span>\n    </button>\n    <button mat-raised-button (click)=\"services.dialogRef.close()\">\n      <mat-icon fontIcon=\"close\"/>\n      <span>Cancel</span>\n    </button>\n  </mat-dialog-actions>\n}", styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}form{display:grid;gap:1rem}mat-dialog-actions{display:grid;justify-content:center;grid-template-columns:auto auto;gap:1rem}#error{color:red}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"], dependencies: [{ kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "mode", "value", "diameter", "strokeWidth"], exportAs: ["matProgressSpinner"] }, { kind: "component", type: MatSlideToggle, selector: "mat-slide-toggle", inputs: ["name", "id", "labelPosition", "aria-label", "aria-labelledby", "aria-describedby", "required", "color", "disabled", "disableRipple", "tabIndex", "checked", "hideIcon"], outputs: ["change", "toggleChange"], exportAs: ["matSlideToggle"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: LoginFormComponent, decorators: [{
            type: Component,
            args: [{ standalone: true, imports: [
                        MatButton,
                        MatDialogActions,
                        MatDialogContent,
                        MatFormField,
                        MatIcon,
                        MatInput,
                        MatProgressSpinner,
                        MatSlideToggle,
                        ReactiveFormsModule
                    ], template: "<h2 mat-dialog-title>\n  @if (services.authentication.authenticating) {\n    <span>Authenticating...</span>\n  } @else {\n    <span>Login</span>\n  }\n</h2>\n\n<mat-dialog-content>\n  @if (services.authentication.authenticating) {\n    <div id=\"spinner\">\n      <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"/>\n    </div>\n  } @else if (errorMessage) {\n    <div id=\"error\">\n      {{ errorMessage }}\n    </div>\n  } @else {\n    <form [formGroup]=\"form\">\n      <mat-form-field>\n        <input matInput formControlName=\"username\" placeholder=\"Username\" (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n      <mat-form-field>\n        <input matInput formControlName=\"password\" type=\"password\" placeholder=\"Password\" (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n      @if (services.authentication.options.showRememberMeOption) {\n        <mat-slide-toggle [checked]=\"!services.authentication.useSessionStorage\" (change)=\"changeTokenStorageMode($event.checked)\">\n          Remember me next time\n        </mat-slide-toggle>\n      }\n    </form>\n  }\n</mat-dialog-content>\n\n@if (!services.authentication.authenticating) {\n  <mat-dialog-actions>\n    <button mat-raised-button color=\"primary\" (click)=\"authenticate()\"\n      [disabled]=\"form.invalid\">\n      <mat-icon fontIcon=\"done\"/>\n      <span>OK</span>\n    </button>\n    <button mat-raised-button (click)=\"services.dialogRef.close()\">\n      <mat-icon fontIcon=\"close\"/>\n      <span>Cancel</span>\n    </button>\n  </mat-dialog-actions>\n}", styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}form{display:grid;gap:1rem}mat-dialog-actions{display:grid;justify-content:center;grid-template-columns:auto auto;gap:1rem}#error{color:red}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"] }]
        }] });

class LoginComponent {
    constructor() {
        this.#services = {
            dialog: inject(MatDialog)
        };
        this.services = {
            authentication: inject(MatAuthenticationService)
        };
        //#endregion
        this.adminGroup = input();
        this.additionalInfo = input();
    }
    #services;
    login() {
        this.#services.dialog.open(LoginFormComponent, {
            data: {
                adminGroup: this.adminGroup(),
                additionalInfo: this.additionalInfo()
            }
        });
    }
    confirmLogout() {
        this.#services.dialog.open(ConfirmationComponent, {
            data: { message: `Are you sure you want to logout?` }
        })
            .afterClosed()
            .subscribe(result => {
            if (result) {
                this.services.authentication.logout();
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: LoginComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.5", type: LoginComponent, isStandalone: true, selector: "cp-login", inputs: { adminGroup: { classPropertyName: "adminGroup", publicName: "adminGroup", isSignal: true, isRequired: false, transformFunction: null }, additionalInfo: { classPropertyName: "additionalInfo", publicName: "additionalInfo", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0, template: "<div id=\"user-id\">\n  <!-- Logged out -->\n  <!-- Logged in -->\n  @if (services.authentication.authenticated) {\n    <!-- With photo -->\n    @if (services.authentication.authenticatedUser?.photoUrl) {\n      <img\n        id=\"authenticated-user-image\"\n        [src]=\"services.authentication.authenticatedUser?.photoUrl\"\n        matTooltip=\"Logout\"\n        (click)=\"confirmLogout()\" />\n    } @else {\n      <!-- Without photo -->\n      <mat-icon\n        fontIcon=\"account_circle\"\n        matTooltip=\"Logout\"\n        (click)=\"confirmLogout()\">\n      </mat-icon>\n    }\n    <!-- Name -->\n    <div id=\"user-name\">\n      {{ services.authentication.authenticatedUser?.displayName }}\n    </div>\n  } @else {\n    <mat-icon\n      fontIcon=\"account_circle\"\n      matTooltip=\"Login\"\n      (click)=\"login()\">\n    </mat-icon>\n  }\n</div>", styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}mat-icon{font-size:2em!important;height:2em!important;width:2em!important}img{border-radius:100%;width:2em;height:2em}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"], dependencies: [{ kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: LoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-login', standalone: true, imports: [
                        MatIcon,
                    ], template: "<div id=\"user-id\">\n  <!-- Logged out -->\n  <!-- Logged in -->\n  @if (services.authentication.authenticated) {\n    <!-- With photo -->\n    @if (services.authentication.authenticatedUser?.photoUrl) {\n      <img\n        id=\"authenticated-user-image\"\n        [src]=\"services.authentication.authenticatedUser?.photoUrl\"\n        matTooltip=\"Logout\"\n        (click)=\"confirmLogout()\" />\n    } @else {\n      <!-- Without photo -->\n      <mat-icon\n        fontIcon=\"account_circle\"\n        matTooltip=\"Logout\"\n        (click)=\"confirmLogout()\">\n      </mat-icon>\n    }\n    <!-- Name -->\n    <div id=\"user-name\">\n      {{ services.authentication.authenticatedUser?.displayName }}\n    </div>\n  } @else {\n    <mat-icon\n      fontIcon=\"account_circle\"\n      matTooltip=\"Login\"\n      (click)=\"login()\">\n    </mat-icon>\n  }\n</div>", styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}mat-icon{font-size:2em!important;height:2em!important;width:2em!important}img{border-radius:100%;width:2em;height:2em}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"] }]
        }] });

class MatAuthenticationModule {
    static forRoot(options) {
        return {
            ngModule: MatAuthenticationModule,
            providers: [
                {
                    provide: MatAuthenticationServiceOptionsToken,
                    useValue: options
                }
            ]
        };
    }
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('MatAuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationModule, deps: [{ token: MatAuthenticationModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationModule, imports: [CommonModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatProgressSpinnerModule,
            MatSlideToggleModule,
            LoginComponent,
            LoginFormComponent], exports: [LoginComponent,
            LoginFormComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationModule, imports: [CommonModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatProgressSpinnerModule,
            MatSlideToggleModule,
            LoginComponent,
            LoginFormComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MatAuthenticationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule,
                        MatProgressSpinnerModule,
                        MatSlideToggleModule,
                        LoginComponent,
                        LoginFormComponent
                    ],
                    exports: [
                        LoginComponent,
                        LoginFormComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: MatAuthenticationModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LoginComponent, LoginFormComponent, MatAuthenticationModule, MatAuthenticationService, MatAuthenticationServiceOptionsToken };
//# sourceMappingURL=cleavelandprice-ngx-lib-authentication-material.mjs.map
