import { AuthenticationServiceOptionsToken } from '@cleavelandprice/ngx-lib/authentication';
export * from '@cleavelandprice/ngx-lib/authentication';
import { HttpClient } from '@angular/common/http';
import * as i0 from '@angular/core';
import { inject, output, Injectable, Optional, Inject, NgModule, SkipSelf } from '@angular/core';
import { NgxLibServiceBase } from '@cleavelandprice/ngx-lib';
import { CommonModule } from '@angular/common';

class AuthenticationObjectService extends NgxLibServiceBase {
    //#region Fields
    #services;
    //#endregion
    //#region Properties
    get useSessionStorage() {
        return !!localStorage.getItem('storeTokenInSession');
    }
    get storage() {
        return this.useSessionStorage ?
            sessionStorage :
            localStorage;
    }
    //#endregion
    //#region Lifecycle
    constructor(options) {
        super(options);
        this.options = options;
        //#region Fields
        this.#services = {
            //config: inject(ServiceConfig, { optional: true }) ?? new ServiceConfig(),
            http: inject(HttpClient)
        };
        this.authenticatedChanged = output();
        this.authenticatingChanged = output();
        this.authenticationError = output();
        this.authenticating = false; // Flag set to true while the service is attempting to authenticate the user
        this.authenticated = false; // Flag set to true when the user is successfully authenticated
        this.options = {
            ...options,
            tokenName: 'userObject',
            authenticationEndpoint: '/authenticate'
        };
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    //Authenticate the user and store the token in Local Storage
    login(username, password, adminGroup, additionalInfo) {
        const request = {
            username,
            password,
            adminGroup,
            additionalInfo,
            appName: this.options.appName
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.#services.http.post(`${this.apiUrl}${this.options.authenticationEndpoint}`, request)
            .subscribe({
            next: (user) => {
                if (user) {
                    this.validateUser(user);
                }
                else {
                    this.logout();
                }
            },
            error: (err) => {
                this.authenticating = false;
                this.authenticatingChanged.emit(this.authenticating);
                this.authenticationError.emit(err);
            }
        });
    }
    //Logout the user and delete the token from Local Storage
    logout() {
        if (this.storage.getItem(this.options.tokenName)) {
            this.storage.removeItem(this.options.tokenName);
        }
        this.authenticatedUser = undefined;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    }
    validateUser(token) {
        this.authenticatedUser = {
            admin: false, // This type of authentication has no concept of Admin
            displayName: token.displayName,
            accountName: token.sAMAccountName,
            distinguishedName: token.distinguishedName,
            employeeNumber: token.employeeNumber,
            memberOf: token.memberOf.join(',')
        };
        if (this.options.tokenName) {
            this.storage.setItem(this.options.tokenName, JSON.stringify(token));
        }
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    checkForExistingToken() {
        if (this.options.tokenName) {
            const token = this.storage.getItem(this.options.tokenName);
            if (token) {
                this.validateUser(JSON.parse(token));
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectService, deps: [{ token: AuthenticationServiceOptionsToken, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [AuthenticationServiceOptionsToken]
                }] }] });

class AuthenticationObjectModule {
    static forRoot(options) {
        return {
            ngModule: AuthenticationObjectModule,
            providers: [
                {
                    provide: AuthenticationServiceOptionsToken,
                    useValue: options
                }
            ]
        };
    }
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationObjectModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectModule, deps: [{ token: AuthenticationObjectModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectModule, imports: [CommonModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: AuthenticationObjectModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule
                    ],
                    exports: []
                }]
        }], ctorParameters: () => [{ type: AuthenticationObjectModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationObjectModule, AuthenticationObjectService };
//# sourceMappingURL=cleavelandprice-ngx-lib-authentication-object.mjs.map
