import * as i0 from '@angular/core';
import { input, output, Component, inject, NgModule } from '@angular/core';
import * as i6 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i1 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i2 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i3 from '@angular/material/dialog';
import { MatDialogModule, MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import * as i4 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i5 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import { CommonModule } from '@angular/common';

var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
    ConfirmationDialogMode[ConfirmationDialogMode["Custom"] = 3] = "Custom";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));

var DialogType;
(function (DialogType) {
    DialogType[DialogType["Choice"] = 0] = "Choice";
    DialogType[DialogType["Confirmation"] = 1] = "Confirmation";
    DialogType[DialogType["Input"] = 2] = "Input";
    DialogType[DialogType["Message"] = 3] = "Message";
})(DialogType || (DialogType = {}));

class BaseComponent {
    constructor() {
        // This is so that DialogType can be accessible from the HTML template
        this.DialogType = DialogType;
        this.dialogType = input(DialogType.Message);
        this.data = input.required();
        this.closed = output();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
    }
    get #customTrueFalseTextValid() {
        return this.data().customTrueFalseText?.length === 2;
    }
    get customTrueText() {
        return this.#customTrueFalseTextValid ?
            this.data().customTrueFalseText[0] :
            undefined;
    }
    get customFalseText() {
        return this.#customTrueFalseTextValid ?
            this.data().customTrueFalseText[1] :
            undefined;
    }
    get choices() {
        return this.dialogType() === DialogType.Choice ?
            this.data().choices :
            null;
    }
    ngOnInit() {
        this.userInput = this.data().value;
    }
    close() {
        let data;
        switch (this.dialogType()) {
            case DialogType.Message:
                data = this.data().checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case DialogType.Input:
                data = this.data().checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case DialogType.Confirmation:
                data = this.data().checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    }
    cancel() {
        let data;
        if (this.dialogType() === DialogType.Confirmation) {
            data = this.data().checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: BaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.5", type: BaseComponent, isStandalone: true, selector: "cp-dialog-base", inputs: { dialogType: { classPropertyName: "dialogType", publicName: "dialogType", isSignal: true, isRequired: false, transformFunction: null }, data: { classPropertyName: "data", publicName: "data", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { closed: "closed" }, ngImport: i0, template: "@if (data().title) {\n  <h2 mat-dialog-title [innerHTML]=\"data().title\"></h2>\n}\n\n<mat-dialog-content>\n  @if (data().message) {\n    <div [innerHTML]=\"data().message\"></div>\n  }\n\n  @if (dialogType() === DialogType.Input) {\n    <mat-form-field>\n      <textarea matInput [placeholder]=\"data().placeholder ?? ''\" [(ngModel)]=\"userInput\"></textarea>\n    </mat-form-field>\n  }\n\n  @if (data().checkboxMessage) {\n    <div id=\"checkbox\">\n      <mat-checkbox [(ngModel)]=\"checkboxValue\">\n        <span [innerHTML]=\"data().checkboxMessage\"></span>\n      </mat-checkbox>\n    </div>\n  }\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  @if (dialogType() !== DialogType.Choice) {\n    <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType() === DialogType.Input && !userInput\">\n      <span>\n        @switch (data().mode) {\n          @case (ConfirmationDialogMode.YesNo) {\n            <span>Yes</span>\n          }\n          @case (ConfirmationDialogMode.TrueFalse) {\n            <span>True</span>\n          }\n          @case (ConfirmationDialogMode.Custom) {\n            <span>{{ customTrueText }}</span>\n          }\n          @default {\n            <span>OK</span>\n          }\n        }\n      </span>\n    </button>\n    @if (dialogType() !== DialogType.Message) {\n      <button mat-raised-button (click)=\"cancel()\">\n        <span>\n          @switch (data().mode) {\n            @case (ConfirmationDialogMode.YesNo) {\n              <span>No</span>\n            }\n            @case (ConfirmationDialogMode.TrueFalse) {\n              <span>False</span>\n            }\n            @case (ConfirmationDialogMode.Custom) {\n              <span>{{ customFalseText }}</span>\n            }\n            @default {\n              <span>Cancel</span>\n            }\n          }\n        </span>\n      </button>\n    }\n  }\n\n  @if (dialogType() === DialogType.Choice) {\n    @for (choice of choices; track choice; let i = $index) {\n      <button mat-raised-button [matDialogClose]=\"i\">\n        <span>{{ choice }}</span>\n      </button>\n    }\n  }\n</mat-dialog-actions>", styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}\n"], dependencies: [{ kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i1.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "ngmodule", type: MatCheckboxModule }, { kind: "component", type: i2.MatCheckbox, selector: "mat-checkbox", inputs: ["aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "disableRipple", "tabIndex", "color", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i3.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i3.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i3.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i3.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "component", type: i4.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i5.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i6.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i6.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i6.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: BaseComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-base', standalone: true, imports: [
                        MatButtonModule,
                        MatCheckboxModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatInputModule,
                        FormsModule
                    ], template: "@if (data().title) {\n  <h2 mat-dialog-title [innerHTML]=\"data().title\"></h2>\n}\n\n<mat-dialog-content>\n  @if (data().message) {\n    <div [innerHTML]=\"data().message\"></div>\n  }\n\n  @if (dialogType() === DialogType.Input) {\n    <mat-form-field>\n      <textarea matInput [placeholder]=\"data().placeholder ?? ''\" [(ngModel)]=\"userInput\"></textarea>\n    </mat-form-field>\n  }\n\n  @if (data().checkboxMessage) {\n    <div id=\"checkbox\">\n      <mat-checkbox [(ngModel)]=\"checkboxValue\">\n        <span [innerHTML]=\"data().checkboxMessage\"></span>\n      </mat-checkbox>\n    </div>\n  }\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  @if (dialogType() !== DialogType.Choice) {\n    <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType() === DialogType.Input && !userInput\">\n      <span>\n        @switch (data().mode) {\n          @case (ConfirmationDialogMode.YesNo) {\n            <span>Yes</span>\n          }\n          @case (ConfirmationDialogMode.TrueFalse) {\n            <span>True</span>\n          }\n          @case (ConfirmationDialogMode.Custom) {\n            <span>{{ customTrueText }}</span>\n          }\n          @default {\n            <span>OK</span>\n          }\n        }\n      </span>\n    </button>\n    @if (dialogType() !== DialogType.Message) {\n      <button mat-raised-button (click)=\"cancel()\">\n        <span>\n          @switch (data().mode) {\n            @case (ConfirmationDialogMode.YesNo) {\n              <span>No</span>\n            }\n            @case (ConfirmationDialogMode.TrueFalse) {\n              <span>False</span>\n            }\n            @case (ConfirmationDialogMode.Custom) {\n              <span>{{ customFalseText }}</span>\n            }\n            @default {\n              <span>Cancel</span>\n            }\n          }\n        </span>\n      </button>\n    }\n  }\n\n  @if (dialogType() === DialogType.Choice) {\n    @for (choice of choices; track choice; let i = $index) {\n      <button mat-raised-button [matDialogClose]=\"i\">\n        <span>{{ choice }}</span>\n      </button>\n    }\n  }\n</mat-dialog-actions>", styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}\n"] }]
        }] });

class ChoiceComponent {
    constructor() {
        this.services = {
            data: inject(MAT_DIALOG_DATA),
            dialogRef: inject((MatDialogRef))
        };
        this.dialogType = DialogType.Choice;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: ChoiceComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.5", type: ChoiceComponent, isStandalone: true, selector: "cp-dialog-choice", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: ChoiceComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-choice', standalone: true, imports: [BaseComponent], template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }] });

class ConfirmationComponent {
    constructor() {
        this.services = {
            data: inject(MAT_DIALOG_DATA),
            dialogRef: inject((MatDialogRef))
        };
        this.dialogType = DialogType.Confirmation;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: ConfirmationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.5", type: ConfirmationComponent, isStandalone: true, selector: "cp-dialog-confirmation", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: ConfirmationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-confirmation', standalone: true, imports: [BaseComponent], template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }] });

class InputComponent {
    constructor() {
        this.services = {
            data: inject(MAT_DIALOG_DATA),
            dialogRef: inject((MatDialogRef))
        };
        this.dialogType = DialogType.Input;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InputComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.5", type: InputComponent, isStandalone: true, selector: "cp-dialog-input", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-input', standalone: true, imports: [BaseComponent], template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }] });

class MessageComponent {
    constructor() {
        this.services = {
            data: inject(MAT_DIALOG_DATA),
            dialogRef: inject((MatDialogRef))
        };
        this.dialogType = DialogType.Message;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MessageComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.5", type: MessageComponent, isStandalone: true, selector: "cp-dialog-message", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: MessageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-message', standalone: true, imports: [BaseComponent], template: "<cp-dialog-base\n  [data]=\"services.data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"services.dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }] });

class DialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: DialogModule, imports: [CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatFormFieldModule,
            MatInputModule,
            BaseComponent,
            ChoiceComponent,
            ConfirmationComponent,
            InputComponent,
            MessageComponent], exports: [BaseComponent,
            ChoiceComponent,
            ConfirmationComponent,
            InputComponent,
            MessageComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: DialogModule, imports: [CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatFormFieldModule,
            MatInputModule,
            BaseComponent,
            ChoiceComponent,
            ConfirmationComponent,
            InputComponent,
            MessageComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatInputModule,
                        BaseComponent,
                        ChoiceComponent,
                        ConfirmationComponent,
                        InputComponent,
                        MessageComponent
                    ],
                    exports: [
                        BaseComponent,
                        ChoiceComponent,
                        ConfirmationComponent,
                        InputComponent,
                        MessageComponent
                    ]
                }]
        }] });

/*export const CP_DIALOG_COMPONENTS = [
    ChoiceComponent,
    ConfirmationComponent,
    InputComponent,
    MessageComponent
] as const;*/
/*export const CP_DIALOG_ENUMS = {
    ConfirmationDialogMode,
    DialogType
 } as const;*/

/**
 * Generated bundle index. Do not edit.
 */

export { BaseComponent, ChoiceComponent, ConfirmationComponent, ConfirmationDialogMode, DialogModule, DialogType, InputComponent, MessageComponent };
//# sourceMappingURL=cleavelandprice-ngx-lib-dialog.mjs.map
