import * as i0 from '@angular/core';
import { inject, Component, viewChild, output, forwardRef, Input, NgModule, Optional, SkipSelf } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule, NG_VALUE_ACCESSOR, ReactiveFormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogActions, MatDialogClose, MatDialogContent, MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { QuillEditorComponent, QuillModule as QuillModule$1 } from 'ngx-quill';
import { NgTemplateOutlet, CommonModule } from '@angular/common';
import { MatIcon, MatIconModule } from '@angular/material/icon';
import { MatTooltip, MatTooltipModule } from '@angular/material/tooltip';
import { MatButton, MatButtonModule } from '@angular/material/button';
import { MatFormField, MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule } from '@angular/material/input';

class Buttons {
    constructor() {
        //#region Font Style
        this.bold = true;
        this.italic = true;
        this.strike = true;
        this.underline = true;
        //#endregion
        //#region Media
        this.link = true;
        this.image = true;
        this.video = true;
        //#endregion
        //#region Block Style
        this.blockquote = true;
        this.codeblock = true;
        //#endregion
        //#region Heading Style
        this.h1 = true;
        this.h2 = true;
        //#endregion
        //#region Color
        this.color = true;
        //#endregion
        //#region List Style
        this.bulleted = true;
        this.ordered = true;
        //#endregion
        //#region Script Style
        this.subScript = true;
        this.superScript = true;
        //#endregion
        //#region Indent Style
        this.increaseIndent = true;
        this.decreaseIndent = true;
        //#endregion
        //#region DropDowns
        this.align = true;
        this.font = true;
        this.fontSize = true;
        this.headingStyle = true;
        //#endregion
        //#region Single Buttons
        this.clean = true;
        this.formula = true;
        this.rtl = true;
        this.editorSize = true;
        this.rawEditor = false;
        //#endregion
    }
}

class Icons {
    constructor() {
        this.maximize = 'open_in_full';
        this.minimize = 'close_fullscreen';
        this.popout = 'open_in_full';
        this.popin = 'done';
    }
}

class Tooltips {
    constructor() {
        //#region Font Style
        this.bold = 'Bold';
        this.italic = 'Italic';
        this.strike = 'Strikethrough';
        this.underline = 'Underline';
        //#endregion
        //#region Media
        this.link = 'Link';
        this.image = 'Insert Image';
        this.video = 'Insert Video';
        //#endregion
        //#region Block Style
        this.blockquote = 'Blockquote';
        this.codeblock = 'Code Block';
        //#endregion
        //#region Heading Style
        this.h1 = 'Heading 1';
        this.h2 = 'Heading 2';
        //#endregion
        //#region Color
        this.color = 'Font / Background Color';
        //#endregion
        //#region List Style
        this.bulleted = 'Bulleted List';
        this.ordered = 'Ordered List';
        //#endregion
        //#region Script Style
        this.subScript = 'Subscript';
        this.superScript = 'Superscript';
        //#endregion
        //#region Indent Style
        this.increaseIndent = 'Increase Indent';
        this.decreaseIndent = 'Decrease Indent';
        //#endregion
        //#region DropDowns
        this.align = 'Align';
        this.font = 'Font';
        this.fontSize = 'Font Size';
        this.headingStyle = 'Heading';
        //#endregion
        //#region Single Buttons
        this.clean = 'Clean';
        this.formula = 'Formula';
        this.rtl = 'Right-To-Left';
        this.maximize = 'Maximize';
        this.minimize = 'Minimize';
        this.popout = 'Popout';
        this.popin = 'Done';
        this.rawEditor = 'Edit raw HTML (dangerous!)';
        //#endregion
    }
}

class Config {
    constructor() {
        this.buttons = new Buttons();
        this.tooltips = new Tooltips();
        this.icons = new Icons();
        //#region These can be overriden via @Input()
        this.format = 'html';
        this.height = '50vh';
        this.width = '100%';
        this.fullscreenHeight = '85vh';
        this.fullscreenWidth = '100%';
        this.enableTooltips = true;
        this.fullscreen = false;
        this.fullscreenMode = 'popout';
        this.readonly = false;
        this.applyReadonlyStyle = true;
        this.showToolbar = true;
        this.showBorder = true;
        //#region Optional Quill modules
        this.imageResizeModule = true;
        this.imageDropModule = true;
        //mentionModule = true;
        this.syntaxModule = true;
        //#endregion
        //#endregion
        //#region Groups
        this.showBlockStyle = () => this.buttons.blockquote || this.buttons.codeblock;
        this.showFontStyle = () => this.buttons.bold || this.buttons.italic || this.buttons.strike || this.buttons.underline;
        this.showQuickHeadingStyle = () => this.buttons.h1 || this.buttons.h2;
        this.showIndentStyle = () => this.buttons.decreaseIndent || this.buttons.increaseIndent;
        this.showListStyle = () => this.buttons.bulleted || this.buttons.ordered;
        this.showMedia = () => this.buttons.link || this.buttons.image || this.buttons.video;
        this.showScriptStyle = () => this.buttons.subScript || this.buttons.superScript;
        //#endregion
    }
}

class RawComponent {
    constructor() {
        this.data = inject(MAT_DIALOG_DATA);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: RawComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.5", type: RawComponent, isStandalone: true, selector: "cpquill-raw", ngImport: i0, template: "<mat-dialog-content>\n    <form>\n        <mat-form-field appearance=\"outline\">\n            <textarea matInput [(ngModel)]=\"data\" name=\"data\"></textarea>\n        </mat-form-field>\n    </form>\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <button mat-raised-button color=\"warn\" mat-dialog-close=\"__DO!!NOT!!UPDATE__\">\n        <mat-icon>cancel</mat-icon>\n        <span>Cancel</span>\n    </button>\n\n    <button mat-raised-button color=\"primary\" [mat-dialog-close]=\"data\">\n        <mat-icon>done</mat-icon>\n        <span>Accept</span>\n    </button>\n</mat-dialog-actions>", styles: ["mat-dialog-content{height:95%;max-height:initial!important}form{width:100%}mat-form-field{width:100%}textarea{height:70vh}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: RawComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cpquill-raw', standalone: true, imports: [
                        FormsModule,
                        MatButton,
                        MatDialogActions,
                        MatDialogClose,
                        MatDialogContent,
                        MatFormField,
                        MatIcon
                    ], template: "<mat-dialog-content>\n    <form>\n        <mat-form-field appearance=\"outline\">\n            <textarea matInput [(ngModel)]=\"data\" name=\"data\"></textarea>\n        </mat-form-field>\n    </form>\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <button mat-raised-button color=\"warn\" mat-dialog-close=\"__DO!!NOT!!UPDATE__\">\n        <mat-icon>cancel</mat-icon>\n        <span>Cancel</span>\n    </button>\n\n    <button mat-raised-button color=\"primary\" [mat-dialog-close]=\"data\">\n        <mat-icon>done</mat-icon>\n        <span>Accept</span>\n    </button>\n</mat-dialog-actions>", styles: ["mat-dialog-content{height:95%;max-height:initial!important}form{width:100%}mat-form-field{width:100%}textarea{height:70vh}\n"] }]
        }] });

class EditorComponent {
    constructor() {
        this.#data = inject(MAT_DIALOG_DATA, { optional: true });
        this.#dialogRef = inject((MatDialogRef), { optional: true });
        this.#dialog = inject(MatDialog);
        //@ViewChild(QuillEditorComponent, { static: false }) editor?: QuillEditorComponent;
        this.editor = viewChild(QuillEditorComponent);
        this.onChange = (_) => { }; // Invoked when the model has been changed
        this.onTouched = () => { }; // Invoked when the model has been touched
        //#endregion
        //#endregion
        this.fullscreenChanged = output();
        //#region Passthrough events
        this.onBlur = output();
        this.onContentChanged = output();
        this.onEditorChanged = output();
        this.onEditorCreated = output();
        this.onFocus = output();
        this.onSelectionChanged = output();
    }
    #data;
    #dialogRef;
    #dialog;
    //#endregion
    ngOnInit() {
        this.initialize();
        /*if (!this.users) {
          this.activeDirectoryService.getUsers().subscribe(users =>
            this.users = users
          );
        }*/
    }
    initialize() {
        this.config = this.config ?? this.#data?.config ?? new Config();
        this.value = this.value ?? this.#data?.value;
        // Moved to client responsibility
        /*if (this.imageDropModule) {
          Quill.register('modules/imageDrop', ImageDrop);
        }*/
        this.placeholder = this.placeholder ?? this.#data?.placeholder;
        //this.users = this.users ?? this.data?.users;
        this.imageDropModule = this.imageDropModule ?? this.#data?.imageDropModule ?? this.config.imageDropModule;
        this.imageResizeModule = this.imageResizeModule ?? this.#data?.imageResizeModule ?? this.config.imageResizeModule;
        this.syntaxModule = this.syntaxModule ?? this.#data?.syntaxModule ?? this.config.syntaxModule;
        this.format = this.format ?? this.#data?.format ?? this.config.format;
        this.height = this.height ?? this.#data?.height ?? this.config.height;
        this.width = this.width ?? this.#data?.width ?? this.config.width;
        this.fullscreenHeight = this.fullscreenHeight ?? this.#data?.maxHeight ?? this.config.fullscreenHeight;
        this.fullscreenWidth = this.fullscreenWidth ?? this.#data?.maxWidth ?? this.config.fullscreenWidth;
        this.fullscreenMode = this.fullscreenMode ?? this.#data?.fullscreenMode ?? this.config.fullscreenMode;
        this.enableTooltips = this.enableTooltips !== undefined ?
            this.enableTooltips :
            this.#data?.enableTooltips ?? this.config.enableTooltips;
        this.fullscreen = this.fullscreen !== undefined ?
            this.fullscreen :
            this.#data?.fullscreen ?? this.config.fullscreen;
        this.readonly = this.readonly !== undefined ?
            this.readonly :
            this.#data?.readonly ?? this.config.readonly;
        this.applyReadonlyStyle = this.applyReadonlyStyle !== undefined ?
            this.applyReadonlyStyle :
            this.#data?.applyReadonlyStyle ?? this.config.applyReadonlyStyle;
        this.showToolbar = this.showToolbar !== undefined ?
            this.showToolbar :
            this.#data?.showToolbar ?? this.config.showToolbar;
        this.showBorder = this.showBorder !== undefined ?
            this.showBorder :
            this.#data?.showBorder ?? this.config.showBorder;
    }
    toggleFullscreen() {
        if (this.fullscreenMode === 'expand') {
            this.fullscreen = !this.fullscreen;
            this.fullscreenChanged.emit(this.fullscreen);
        }
        else {
            if (this.fullscreen) {
                this.#dialogRef?.close(this.value);
                this.fullscreenChanged.emit(false);
            }
            else {
                const data = {
                    value: this.value,
                    config: this.config,
                    placeholder: this.placeholder,
                    format: this.format,
                    height: this.fullscreenHeight,
                    width: '100%',
                    maxHeight: this.fullscreenHeight,
                    maxWidth: '100%',
                    enableTooltips: this.enableTooltips,
                    fullscreen: true,
                    fullscreenMode: this.fullscreenMode,
                    readonly: this.readonly,
                    applyReadonlyStyle: this.applyReadonlyStyle,
                    showToolbar: this.showToolbar,
                    showBorder: this.showBorder,
                    imageResizeModule: this.imageResizeModule,
                    imageDropModule: this.imageDropModule,
                    syntaxModule: this.syntaxModule
                    //users: this.users
                };
                this.#dialog.open(EditorComponent, {
                    disableClose: true,
                    width: this.fullscreenWidth,
                    height: this.fullscreenHeight,
                    data
                })
                    .afterClosed()
                    .subscribe(value => {
                    this.value = value;
                    this.updateChanges();
                });
                this.fullscreenChanged.emit(true);
            }
        }
    }
    rawEdit() {
        this.#dialog.open(RawComponent, {
            data: this.value,
            disableClose: true,
            height: '90%',
            width: '100%'
        })
            .afterClosed()
            .subscribe(value => {
            if (value === '__DO!!NOT!!UPDATE__') {
                return;
            }
            this.value = value;
        });
    }
    tooltip(val) {
        return this.enableTooltips ? val : '';
    }
    get modules() {
        //if (!this.users) { return undefined; }
        const modules = {};
        if (!this.showToolbar) {
            modules['toolbar'] = [];
        }
        if (this.imageResizeModule) {
            modules['imageResize'] = {};
        }
        if (this.imageDropModule) {
            modules['imageDrop'] = true;
        }
        if (this.syntaxModule) {
            modules['syntax'] = true;
        }
        /*if (this.mentionModule) {
          modules['mention'] = {
            allowedChars: /^[A-Za-z\sÅÄÖåäö]*$/,
    
            onSelect: (item: DOMStringMap, insertItem: any) => {
              const editor = this.editor!.quillEditor
              insertItem(item)
              // necessary because quill-mention triggers changes as 'api' instead of 'user'
              editor.insertText(editor.getLength() - 1, '', 'user')
            },
    
            source: (searchTerm: string, renderList: any) => {
              if (searchTerm.length === 0) {
                renderList(this.users?.map(u => ({ value: `${u.displayName} (${u.sAMAccountName.toLowerCase()})` })), searchTerm)
              } else {
                const matches: any[] = []
    
                this.users!.forEach((entry) => {
                  if (
                    entry.displayName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1 ||
                    entry.sAMAccountName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1
                    ) {
                    matches.push({ value: `${entry.displayName} (${entry.sAMAccountName.toLowerCase()})` })
                  }
                })
    
                renderList(matches, searchTerm)
              }
            }
          };
        }*/
        return modules;
    }
    //#region ControlValueAccessor methods
    // Method that is invoked on an update of a model.
    updateChanges() {
        this.onChange(this.value);
    }
    //#region ControlValueAccessor Overrides
    // Writes a new item to the element.
    writeValue(value) {
        this.value = value;
        this.updateChanges();
    }
    // Registers a callback function that should be called when the control's value changes in the UI.
    registerOnChange(fn) {
        this.onChange = fn;
    }
    // Registers a callback function that should be called when the control receives a blur event.
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: EditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.5", type: EditorComponent, isStandalone: true, selector: "cpquill-editor", inputs: { config: "config", placeholder: "placeholder", format: "format", height: "height", width: "width", fullscreenHeight: "fullscreenHeight", fullscreenWidth: "fullscreenWidth", fullscreenMode: "fullscreenMode", enableTooltips: "enableTooltips", fullscreen: "fullscreen", readonly: "readonly", applyReadonlyStyle: "applyReadonlyStyle", showToolbar: "showToolbar", showBorder: "showBorder", imageResizeModule: "imageResizeModule", imageDropModule: "imageDropModule", syntaxModule: "syntaxModule" }, outputs: { fullscreenChanged: "fullscreenChanged", onBlur: "onBlur", onContentChanged: "onContentChanged", onEditorChanged: "onEditorChanged", onEditorCreated: "onEditorCreated", onFocus: "onFocus", onSelectionChanged: "onSelectionChanged" }, providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => EditorComponent),
                multi: true
            }], viewQueries: [{ propertyName: "editor", first: true, predicate: QuillEditorComponent, descendants: true, isSignal: true }], ngImport: i0, template: "<ng-container>\n  <form>\n    <quill-editor name=\"editor\"\n      [(ngModel)]=\"value\"\n      (ngModelChange)=\"updateChanges()\"\n\n      [placeholder]=\"placeholder ?? ''\"\n      [format]=\"format\"\n      [style.height]=\"fullscreen ? fullscreenHeight : height\"\n      [style.width]=\"fullscreen ? fullscreenWidth : width\"\n      [readOnly]=\"readonly ?? false\"\n      [class.readonly]=\"readonly && applyReadonlyStyle\"\n      [class.no-toolbar]=\"!showToolbar\"\n      [class.no-border]=\"!showBorder\"\n      [modules]=\"modules\"\n\n      (onBlur)=\"onBlur.emit($event)\"\n      (onContentChanged)=\"onContentChanged.emit($event)\"\n      (onEditorChanged)=\"onEditorChanged.emit($event)\"\n      (onEditorCreated)=\"onEditorCreated.emit()\"\n      (onFocus)=\"onFocus.emit($event)\"\n      (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\n\n      @if (showToolbar) {\n        <div quill-editor-toolbar>\n          <ng-container [ngTemplateOutlet]=\"toolbar\"/>\n          <ng-container [ngTemplateOutlet]=\"editorSize\"/>\n        </div>\n      }\n    </quill-editor>\n  </form>\n</ng-container>\n\n<ng-template #toolbar>\n  <div>\n    <ng-container [ngTemplateOutlet]=\"fontStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"blockStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"headingStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"listStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"scriptStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"indentStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"rtl\"/>\n    <ng-container [ngTemplateOutlet]=\"fontSize\"/>\n    <ng-container [ngTemplateOutlet]=\"heading\"/>\n    <ng-container [ngTemplateOutlet]=\"color\"/>\n    <ng-container [ngTemplateOutlet]=\"font\"/>\n    <ng-container [ngTemplateOutlet]=\"align\"/>\n    <ng-container [ngTemplateOutlet]=\"clean\"/>\n    <ng-container [ngTemplateOutlet]=\"formula\"/>\n    <ng-container [ngTemplateOutlet]=\"media\"/>\n  </div>\n</ng-template>\n\n<ng-template #fontStyle>\n  @if (config!.showFontStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.bold) {\n        <button class=\"ql-bold\"           [matTooltip]=\"tooltip(config!.tooltips.bold)\"></button>\n      }\n      @if (config!.buttons.italic) {\n        <button class=\"ql-italic\"       [matTooltip]=\"tooltip(config!.tooltips.italic)\"></button>\n      }\n      @if (config!.buttons.underline) {\n        <button class=\"ql-underline\" [matTooltip]=\"tooltip(config!.tooltips.underline)\"></button>\n      }\n      @if (config!.buttons.strike) {\n        <button class=\"ql-strike\"       [matTooltip]=\"tooltip(config!.tooltips.strike)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #blockStyle>\n  @if (config!.showBlockStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.blockquote) {\n        <button class=\"ql-blockquote\" [matTooltip]=\"tooltip(config!.tooltips.blockquote)\"></button>\n      }\n      @if (config!.buttons.codeblock) {\n        <button class=\"ql-code-block\"  [matTooltip]=\"tooltip(config!.tooltips.codeblock)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #headingStyle>\n  @if (config!.showQuickHeadingStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.h1) {\n        <button class=\"ql-header\" value=\"1\" [matTooltip]=\"tooltip(config!.tooltips.h1)\"></button>\n      }\n      @if (config!.buttons.h2) {\n        <button class=\"ql-header\" value=\"2\" [matTooltip]=\"tooltip(config!.tooltips.h2)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #listStyle>\n  @if (config!.showListStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.ordered) {\n        <button class=\"ql-list\" value=\"ordered\"  [matTooltip]=\"tooltip(config!.tooltips.ordered)\"></button>\n      }\n      @if (config!.buttons.bulleted) {\n        <button class=\"ql-list\" value=\"bullet\"  [matTooltip]=\"tooltip(config!.tooltips.bulleted)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #scriptStyle>\n  @if (config!.showScriptStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.subScript) {\n        <button class=\"ql-script\" value=\"sub\"   [matTooltip]=\"tooltip(config!.tooltips.subScript)\"></button>\n      }\n      @if (config!.buttons.superScript) {\n        <button class=\"ql-script\" value=\"super\" [matTooltip]=\"tooltip(config!.tooltips.superScript)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #indentStyle>\n  @if (config!.showIndentStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.decreaseIndent) {\n        <button class=\"ql-indent\" value=\"-1\" [matTooltip]=\"tooltip(config!.tooltips.decreaseIndent)\"></button>\n      }\n      @if (config!.buttons.increaseIndent) {\n        <button class=\"ql-indent\" value=\"+1\" [matTooltip]=\"tooltip(config!.tooltips.increaseIndent)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #rtl>\n  @if (config!.buttons.rtl) {\n    <span class=\"ql-formats\">\n      <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config!.tooltips.rtl)\"></button>\n    </span>\n  }\n</ng-template>\n\n<ng-template #fontSize>\n  @if (config!.buttons.fontSize) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.fontSize)\">\n      <select class=\"ql-size\">\n        <option value=\"small\"></option>\n        <option selected></option>\n        <option value=\"large\"></option>\n        <option value=\"huge\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #heading>\n  @if (config!.buttons.headingStyle) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.headingStyle)\">\n      <select class=\"ql-header\">\n        <option value=\"1\"></option>\n        <option value=\"2\"></option>\n        <option value=\"3\"></option>\n        <option value=\"4\"></option>\n        <option value=\"5\"></option>\n        <option value=\"6\"></option>\n        <option selected=\"selected\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #color>\n  @if (config!.buttons.color) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.color)\">\n      <select class=\"ql-color\"></select>\n      <select class=\"ql-background\"></select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #font>\n  @if (config!.buttons.font) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.font)\">\n      <select class=\"ql-font\">\n        <option selected></option>\n        <option value=\"serif\"></option>\n        <option value=\"monospace\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #align>\n  @if (config!.buttons.align) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.align)\">\n      <select class=\"ql-align\">\n        <option selected></option>\n        <option value=\"center\"></option>\n        <option value=\"right\"></option>\n        <option value=\"justify\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #clean>\n  @if (config!.buttons.clean) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.clean)\">\n      <button class=\"ql-clean\"></button>\n    </span>\n  }\n</ng-template>\n\n<ng-template #media>\n  @if (config!.showMedia()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.link) {\n        <button class=\"ql-link\"  [matTooltip]=\"tooltip(config!.tooltips.link)\"></button>\n      }\n      @if (config!.buttons.image) {\n        <button class=\"ql-image\" [matTooltip]=\"tooltip(config!.tooltips.image)\"></button>\n      }\n      @if (config!.buttons.video) {\n        <button class=\"ql-video\" [matTooltip]=\"tooltip(config!.tooltips.video)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #editorSize>\n  <div>\n    @if (config!.buttons.rawEditor) {\n      <span class=\"ql-formats\">\n        <button id=\"rawdog\"\n          [matTooltip]=\"tooltip(config!.tooltips.rawEditor)\">\n          <mat-icon (click)=\"rawEdit()\">\n            code\n          </mat-icon>\n        </button>\n      </span>\n    }\n\n    @if (config!.buttons.editorSize) {\n      <span class=\"ql-formats\">\n        <button id=\"fullscreen\"\n                [matTooltip]=\"tooltip(fullscreen ?\n                    (fullscreenMode === 'expand' ? config!.tooltips.minimize : config!.tooltips.popin) :\n                    (fullscreenMode === 'expand' ? config!.tooltips.maximize : config!.tooltips.popout))\">\n          <mat-icon (click)=\"toggleFullscreen()\">\n            {{ fullscreen ?\n            (fullscreenMode === 'expand' ? config!.icons.minimize : config!.icons.popin) :\n            (fullscreenMode === 'expand' ? config!.icons.maximize : config!.icons.popout)\n            }}\n          </mat-icon>\n        </button>\n      </span>\n    }\n  </div>\n</ng-template>\n\n<ng-template #formula>\n  @if (config!.buttons.formula) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.formula)\">\n      <button class=\"ql-formula\"></button>\n    </span>\n  }\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.no-toolbar .ql-toolbar{height:0;padding:0;visibility:hidden}::ng-deep quill-editor.no-border .ql-container{border:none}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: QuillEditorComponent, selector: "quill-editor" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: EditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cpquill-editor', standalone: true, imports: [
                        FormsModule,
                        MatIcon,
                        MatTooltip,
                        NgTemplateOutlet,
                        QuillEditorComponent,
                    ], providers: [{
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => EditorComponent),
                            multi: true
                        }], template: "<ng-container>\n  <form>\n    <quill-editor name=\"editor\"\n      [(ngModel)]=\"value\"\n      (ngModelChange)=\"updateChanges()\"\n\n      [placeholder]=\"placeholder ?? ''\"\n      [format]=\"format\"\n      [style.height]=\"fullscreen ? fullscreenHeight : height\"\n      [style.width]=\"fullscreen ? fullscreenWidth : width\"\n      [readOnly]=\"readonly ?? false\"\n      [class.readonly]=\"readonly && applyReadonlyStyle\"\n      [class.no-toolbar]=\"!showToolbar\"\n      [class.no-border]=\"!showBorder\"\n      [modules]=\"modules\"\n\n      (onBlur)=\"onBlur.emit($event)\"\n      (onContentChanged)=\"onContentChanged.emit($event)\"\n      (onEditorChanged)=\"onEditorChanged.emit($event)\"\n      (onEditorCreated)=\"onEditorCreated.emit()\"\n      (onFocus)=\"onFocus.emit($event)\"\n      (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\n\n      @if (showToolbar) {\n        <div quill-editor-toolbar>\n          <ng-container [ngTemplateOutlet]=\"toolbar\"/>\n          <ng-container [ngTemplateOutlet]=\"editorSize\"/>\n        </div>\n      }\n    </quill-editor>\n  </form>\n</ng-container>\n\n<ng-template #toolbar>\n  <div>\n    <ng-container [ngTemplateOutlet]=\"fontStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"blockStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"headingStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"listStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"scriptStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"indentStyle\"/>\n    <ng-container [ngTemplateOutlet]=\"rtl\"/>\n    <ng-container [ngTemplateOutlet]=\"fontSize\"/>\n    <ng-container [ngTemplateOutlet]=\"heading\"/>\n    <ng-container [ngTemplateOutlet]=\"color\"/>\n    <ng-container [ngTemplateOutlet]=\"font\"/>\n    <ng-container [ngTemplateOutlet]=\"align\"/>\n    <ng-container [ngTemplateOutlet]=\"clean\"/>\n    <ng-container [ngTemplateOutlet]=\"formula\"/>\n    <ng-container [ngTemplateOutlet]=\"media\"/>\n  </div>\n</ng-template>\n\n<ng-template #fontStyle>\n  @if (config!.showFontStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.bold) {\n        <button class=\"ql-bold\"           [matTooltip]=\"tooltip(config!.tooltips.bold)\"></button>\n      }\n      @if (config!.buttons.italic) {\n        <button class=\"ql-italic\"       [matTooltip]=\"tooltip(config!.tooltips.italic)\"></button>\n      }\n      @if (config!.buttons.underline) {\n        <button class=\"ql-underline\" [matTooltip]=\"tooltip(config!.tooltips.underline)\"></button>\n      }\n      @if (config!.buttons.strike) {\n        <button class=\"ql-strike\"       [matTooltip]=\"tooltip(config!.tooltips.strike)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #blockStyle>\n  @if (config!.showBlockStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.blockquote) {\n        <button class=\"ql-blockquote\" [matTooltip]=\"tooltip(config!.tooltips.blockquote)\"></button>\n      }\n      @if (config!.buttons.codeblock) {\n        <button class=\"ql-code-block\"  [matTooltip]=\"tooltip(config!.tooltips.codeblock)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #headingStyle>\n  @if (config!.showQuickHeadingStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.h1) {\n        <button class=\"ql-header\" value=\"1\" [matTooltip]=\"tooltip(config!.tooltips.h1)\"></button>\n      }\n      @if (config!.buttons.h2) {\n        <button class=\"ql-header\" value=\"2\" [matTooltip]=\"tooltip(config!.tooltips.h2)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #listStyle>\n  @if (config!.showListStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.ordered) {\n        <button class=\"ql-list\" value=\"ordered\"  [matTooltip]=\"tooltip(config!.tooltips.ordered)\"></button>\n      }\n      @if (config!.buttons.bulleted) {\n        <button class=\"ql-list\" value=\"bullet\"  [matTooltip]=\"tooltip(config!.tooltips.bulleted)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #scriptStyle>\n  @if (config!.showScriptStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.subScript) {\n        <button class=\"ql-script\" value=\"sub\"   [matTooltip]=\"tooltip(config!.tooltips.subScript)\"></button>\n      }\n      @if (config!.buttons.superScript) {\n        <button class=\"ql-script\" value=\"super\" [matTooltip]=\"tooltip(config!.tooltips.superScript)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #indentStyle>\n  @if (config!.showIndentStyle()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.decreaseIndent) {\n        <button class=\"ql-indent\" value=\"-1\" [matTooltip]=\"tooltip(config!.tooltips.decreaseIndent)\"></button>\n      }\n      @if (config!.buttons.increaseIndent) {\n        <button class=\"ql-indent\" value=\"+1\" [matTooltip]=\"tooltip(config!.tooltips.increaseIndent)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #rtl>\n  @if (config!.buttons.rtl) {\n    <span class=\"ql-formats\">\n      <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config!.tooltips.rtl)\"></button>\n    </span>\n  }\n</ng-template>\n\n<ng-template #fontSize>\n  @if (config!.buttons.fontSize) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.fontSize)\">\n      <select class=\"ql-size\">\n        <option value=\"small\"></option>\n        <option selected></option>\n        <option value=\"large\"></option>\n        <option value=\"huge\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #heading>\n  @if (config!.buttons.headingStyle) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.headingStyle)\">\n      <select class=\"ql-header\">\n        <option value=\"1\"></option>\n        <option value=\"2\"></option>\n        <option value=\"3\"></option>\n        <option value=\"4\"></option>\n        <option value=\"5\"></option>\n        <option value=\"6\"></option>\n        <option selected=\"selected\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #color>\n  @if (config!.buttons.color) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.color)\">\n      <select class=\"ql-color\"></select>\n      <select class=\"ql-background\"></select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #font>\n  @if (config!.buttons.font) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.font)\">\n      <select class=\"ql-font\">\n        <option selected></option>\n        <option value=\"serif\"></option>\n        <option value=\"monospace\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #align>\n  @if (config!.buttons.align) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.align)\">\n      <select class=\"ql-align\">\n        <option selected></option>\n        <option value=\"center\"></option>\n        <option value=\"right\"></option>\n        <option value=\"justify\"></option>\n      </select>\n    </span>\n  }\n</ng-template>\n\n<ng-template #clean>\n  @if (config!.buttons.clean) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.clean)\">\n      <button class=\"ql-clean\"></button>\n    </span>\n  }\n</ng-template>\n\n<ng-template #media>\n  @if (config!.showMedia()) {\n    <span class=\"ql-formats\">\n      @if (config!.buttons.link) {\n        <button class=\"ql-link\"  [matTooltip]=\"tooltip(config!.tooltips.link)\"></button>\n      }\n      @if (config!.buttons.image) {\n        <button class=\"ql-image\" [matTooltip]=\"tooltip(config!.tooltips.image)\"></button>\n      }\n      @if (config!.buttons.video) {\n        <button class=\"ql-video\" [matTooltip]=\"tooltip(config!.tooltips.video)\"></button>\n      }\n    </span>\n  }\n</ng-template>\n\n<ng-template #editorSize>\n  <div>\n    @if (config!.buttons.rawEditor) {\n      <span class=\"ql-formats\">\n        <button id=\"rawdog\"\n          [matTooltip]=\"tooltip(config!.tooltips.rawEditor)\">\n          <mat-icon (click)=\"rawEdit()\">\n            code\n          </mat-icon>\n        </button>\n      </span>\n    }\n\n    @if (config!.buttons.editorSize) {\n      <span class=\"ql-formats\">\n        <button id=\"fullscreen\"\n                [matTooltip]=\"tooltip(fullscreen ?\n                    (fullscreenMode === 'expand' ? config!.tooltips.minimize : config!.tooltips.popin) :\n                    (fullscreenMode === 'expand' ? config!.tooltips.maximize : config!.tooltips.popout))\">\n          <mat-icon (click)=\"toggleFullscreen()\">\n            {{ fullscreen ?\n            (fullscreenMode === 'expand' ? config!.icons.minimize : config!.icons.popin) :\n            (fullscreenMode === 'expand' ? config!.icons.maximize : config!.icons.popout)\n            }}\n          </mat-icon>\n        </button>\n      </span>\n    }\n  </div>\n</ng-template>\n\n<ng-template #formula>\n  @if (config!.buttons.formula) {\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.formula)\">\n      <button class=\"ql-formula\"></button>\n    </span>\n  }\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.no-toolbar .ql-toolbar{height:0;padding:0;visibility:hidden}::ng-deep quill-editor.no-border .ql-container{border:none}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"] }]
        }], propDecorators: { config: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], format: [{
                type: Input
            }], height: [{
                type: Input
            }], width: [{
                type: Input
            }], fullscreenHeight: [{
                type: Input
            }], fullscreenWidth: [{
                type: Input
            }], fullscreenMode: [{
                type: Input
            }], enableTooltips: [{
                type: Input
            }], fullscreen: [{
                type: Input
            }], readonly: [{
                type: Input
            }], applyReadonlyStyle: [{
                type: Input
            }], showToolbar: [{
                type: Input
            }], showBorder: [{
                type: Input
            }], imageResizeModule: [{
                type: Input
            }], imageDropModule: [{
                type: Input
            }], syntaxModule: [{
                type: Input
            }] } });

class QuillModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('QuillModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: QuillModule, deps: [{ token: QuillModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: QuillModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatTooltipModule,
            QuillModule$1,
            EditorComponent,
            RawComponent], exports: [EditorComponent,
            RawComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: QuillModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatTooltipModule,
            QuillModule$1,
            EditorComponent,
            RawComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: QuillModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule,
                        MatTooltipModule,
                        QuillModule$1,
                        EditorComponent,
                        RawComponent
                    ],
                    exports: [
                        EditorComponent,
                        RawComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: QuillModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { Buttons, Config, EditorComponent, Icons, QuillModule, RawComponent, Tooltips };
//# sourceMappingURL=cleavelandprice-ngx-lib-quill.mjs.map
