import * as i0 from '@angular/core';
import { input, output, viewChild, Component, NgModule } from '@angular/core';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { MatSort, MatSortHeader, MatSortModule } from '@angular/material/sort';
import { MatTableDataSource, MatCell, MatCellDef, MatColumnDef, MatHeaderCell, MatHeaderCellDef, MatHeaderRow, MatHeaderRowDef, MatNoDataRow, MatRow, MatRowDef, MatTable, MatTableModule } from '@angular/material/table';
import { DatePipe, DecimalPipe, NgStyle, NgClass, CommonModule } from '@angular/common';
import * as i1 from '@angular/forms';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { MatButton, MatIconButton, MatButtonModule } from '@angular/material/button';
import { MatCheckbox, MatCheckboxModule } from '@angular/material/checkbox';
import { MatFormField, MatLabel, MatPrefix, MatFormFieldModule } from '@angular/material/form-field';
import { MatIcon, MatIconModule } from '@angular/material/icon';
import { MatInput, MatInputModule } from '@angular/material/input';
import { MatTooltip, MatTooltipModule } from '@angular/material/tooltip';

class TableComponent {
    constructor() {
        //#region Inputs
        this.title = input('');
        this.tableData = input.required();
        this.columns = input([]);
        this.showPaginator = input(true);
        this.showSearch = input(true);
        this.maxTableHeight = input('50em');
        this.shrinkTable = input(false);
        this.paginatorSticky = input(false);
        this.sortingDataAccessor = input();
        //#endregion
        this.buttonClicked = output();
        this.isMobile = false;
        this.paginator = viewChild(MatPaginator);
        this.sort = viewChild(MatSort);
    }
    ngOnInit() {
        this.dataSource = new MatTableDataSource(this.tableData());
        if (this.sortingDataAccessor()) {
            this.dataSource.sortingDataAccessor = this.sortingDataAccessor();
        }
        this.columnNames = this.columns().map(c => c.field);
        this.#setTablePageSizeOptions();
    }
    ngAfterViewInit() {
        if (this.paginator() && !this.dataSource.paginator) {
            this.dataSource.paginator = this.paginator();
        }
        if (this.sort() && !this.dataSource.sort) {
            this.dataSource.sort = this.sort();
        }
    }
    searchFilterChange(event) {
        const filterValue = event.target.value;
        this.dataSource.filter = filterValue.trim().toLowerCase();
    }
    buttonClick(rowData, field) {
        this.buttonClicked.emit({ rowData, field });
    }
    getNestedFieldValue(rowData, nestedFieldName) {
        if (!nestedFieldName) {
            return;
        }
        return rowData[nestedFieldName];
    }
    #setTablePageSizeOptions(defaultPageIncrement = 50) {
        this.pageSizeOptions = [];
        for (let i = defaultPageIncrement; i < this.dataSource.data.length; i = i + (defaultPageIncrement * 2)) {
            this.pageSizeOptions.push(i);
        }
        this.pageSizeOptions.push(this.dataSource.data.length);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: TableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.5", type: TableComponent, isStandalone: true, selector: "lib-table", inputs: { title: { classPropertyName: "title", publicName: "title", isSignal: true, isRequired: false, transformFunction: null }, tableData: { classPropertyName: "tableData", publicName: "tableData", isSignal: true, isRequired: true, transformFunction: null }, columns: { classPropertyName: "columns", publicName: "columns", isSignal: true, isRequired: false, transformFunction: null }, showPaginator: { classPropertyName: "showPaginator", publicName: "showPaginator", isSignal: true, isRequired: false, transformFunction: null }, showSearch: { classPropertyName: "showSearch", publicName: "showSearch", isSignal: true, isRequired: false, transformFunction: null }, maxTableHeight: { classPropertyName: "maxTableHeight", publicName: "maxTableHeight", isSignal: true, isRequired: false, transformFunction: null }, shrinkTable: { classPropertyName: "shrinkTable", publicName: "shrinkTable", isSignal: true, isRequired: false, transformFunction: null }, paginatorSticky: { classPropertyName: "paginatorSticky", publicName: "paginatorSticky", isSignal: true, isRequired: false, transformFunction: null }, sortingDataAccessor: { classPropertyName: "sortingDataAccessor", publicName: "sortingDataAccessor", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { buttonClicked: "buttonClicked" }, viewQueries: [{ propertyName: "paginator", first: true, predicate: MatPaginator, descendants: true, isSignal: true }, { propertyName: "sort", first: true, predicate: MatSort, descendants: true, isSignal: true }], ngImport: i0, template: "<h3>{{title()}}</h3>\r\n\r\n@if (showSearch()) {\r\n  <mat-form-field appearance=\"outline\">\r\n      <mat-label>Search</mat-label>\r\n      <mat-icon matPrefix>search</mat-icon>\r\n      <input type=\"text\" matInput (keyup)=\"searchFilterChange($event)\">\r\n  </mat-form-field>\r\n}\r\n\r\n<div class=\"table-container\" [ngStyle]=\"{'max-height': maxTableHeight()}\" [class.shrink-table]=\"shrinkTable()\">\r\n    <table mat-table [dataSource]=\"dataSource\" matSort>\r\n      @for (column of columns(); track column) {\r\n        <ng-container [matColumnDef]=\"column.field\">\r\n          <th mat-header-cell *matHeaderCellDef mat-sort-header [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n            <div>{{ column.fieldColumnTitle }}</div>\r\n          </th>\r\n  \r\n          <td mat-cell *matCellDef=\"let data\" [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n            @if(column.isDate) {\r\n              {{ data[column.field] | date:'shortDate' }}\r\n            } @else if (column.isNumber) {\r\n              @if (column.isNumber.needsRounded) {\r\n                @if (column.isNumber.percentage) {\r\n                  {{ data[column.field] | number:'0.0-0' }}%\r\n                } @else {\r\n                  {{ data[column.field] | number:'0.0-0' }}\r\n                }\r\n              } @else {\r\n                @if (column.isNumber.percentage) {\r\n                  {{ data[column.field] | number:'.1-2' }}%\r\n                } @else {\r\n                  {{ data[column.field] | number:'.1-2' }}\r\n                }\r\n              }\r\n            } @else if (column.isCheckbox) {\r\n              <mat-checkbox [(ngModel)]=\"data[column.field]\" [disabled]=\"column.isCheckbox['isDisabled']\" />\r\n            } @else if (column.isHyperlink) {\r\n              <a [href]=\"data[column.isHyperlink.linkField]\" target=\"_blank\">\r\n                {{ data[column.field] }}\r\n              </a>\r\n            } @else if (column.isButton) {\r\n              @if (column.isButton.isIcon) {\r\n                <button mat-icon-button [matTooltip]=\"column.isButton.isIcon.toolTip\" [disabled]=\"column.isButton.isDisabled\"\r\n                  (click)=\"column.isButton.isDisabled ? undefined : buttonClick(data, column.field)\">\r\n                  <mat-icon>{{column.isButton.isIcon.iconName}}</mat-icon>\r\n                </button>\r\n              } @else if (column.isButton.isCheckbox) {\r\n                <mat-checkbox [matTooltip]=\"column.isButton.isCheckbox.toolTip\"\r\n                  [(ngModel)]=\"data[column.field]\" (click)=\"buttonClick(data, column.field)\" />\r\n              } @else {\r\n                <button mat-raised-button [disabled]=\"column.isButton.isDisabled\"\r\n                  [color]=\"column.isButton.isDisabled ? undefined : 'primary'\"\r\n                  [class.button-extra-padding]=\"column.isButton.extraPadding\"\r\n                  (click)=\"column.isButton.isDisabled ? undefined : buttonClick(data, column.field)\">\r\n                  {{column.isButton.text}}\r\n                </button>\r\n              }\r\n            } @else if (column.nestedField) {\r\n              {{ getNestedFieldValue(data[column.field], column.nestedField) }}\r\n            } @else if (column.isEditable) {\r\n                @if (column.isEditable.type === 'textarea') {\r\n                  <textarea style=\"width: 100%;\" [rows]=\"3\" [(ngModel)]=\"data[column.field]\" [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\"></textarea>\r\n                } @else {\r\n                  <input [(ngModel)]=\"data[column.field]\" style=\"width: 55%;\"  [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\" [type]=\"column.isEditable.isNumber ? 'number' : 'text'\">\r\n                }\r\n            } @else {\r\n                {{ data[column.field] }}\r\n            }\r\n          </td>\r\n        </ng-container>\r\n      }\r\n\r\n      <tr mat-header-row *matHeaderRowDef=\"columnNames; sticky: true\"></tr>\r\n      <tr mat-row *matRowDef=\"let row; columns: columnNames;\" class=\"table-row\"></tr>\r\n      <tr mat-row *matNoDataRow>\r\n        <td class=\"mat-cell\" colspan=\"9999\">\r\n          No records exist.\r\n        </td>\r\n      </tr>\r\n    </table>\r\n\r\n    @if (showPaginator()) {\r\n      <mat-paginator [class.paginator-sticky]=\"paginatorSticky()\" [pageSizeOptions]=\"pageSizeOptions\" showFirstLastButtons />\r\n    }\r\n</div>\r\n", styles: [".mat-form-field{width:100%!important}.table-container{display:grid;grid-template-columns:1fr;max-height:50em;overflow:auto;margin:1em .5em .5em;text-align:center!important}.table-container .table{width:100%}:host ::ng-deep .mat-sort-header-container{display:flex;justify-content:center}td,th{text-align:center!important}.shrink-table .mat-mdc-unelevated-button{line-height:1.75em}.shrink-table .mat-mdc-outlined-button{line-height:1.5em;height:1.5em}.shrink-table .mat-mdc-row:hover{background-color:#8f8f8f18;font-weight:700}.shrink-table .mat-mdc-row,tr.mat-row{min-height:1.5em;height:1.5em}.shrink-table .mat-mdc-header-row{min-height:40px}.shrink-table tr.mat-mdc-header-row{height:1.5em;border-radius:5px}.shrink-table .mat-column-tools{min-width:225px;max-width:225px}.shrink-table .mat-mdc-header-cell{font-weight:700}.paginator-sticky{bottom:0;position:sticky;z-index:10}.button-extra-padding{padding-top:1.75em;padding-bottom:1.75em}\n"], dependencies: [{ kind: "pipe", type: DatePipe, name: "date" }, { kind: "pipe", type: DecimalPipe, name: "number" }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: MatCell, selector: "mat-cell, td[mat-cell]" }, { kind: "directive", type: MatCellDef, selector: "[matCellDef]" }, { kind: "component", type: MatCheckbox, selector: "mat-checkbox", inputs: ["aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "disableRipple", "tabIndex", "color", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { kind: "directive", type: MatColumnDef, selector: "[matColumnDef]", inputs: ["matColumnDef"] }, { kind: "component", type: MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { kind: "directive", type: MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { kind: "component", type: MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { kind: "directive", type: MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "component", type: MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }, { kind: "directive", type: MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "directive", type: MatLabel, selector: "mat-label" }, { kind: "directive", type: MatNoDataRow, selector: "ng-template[matNoDataRow]" }, { kind: "component", type: MatPaginator, selector: "mat-paginator", inputs: ["color", "pageIndex", "length", "pageSize", "pageSizeOptions", "hidePageSize", "showFirstLastButtons", "selectConfig", "disabled"], outputs: ["page"], exportAs: ["matPaginator"] }, { kind: "directive", type: MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "component", type: MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { kind: "directive", type: MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { kind: "directive", type: MatSort, selector: "[matSort]", inputs: ["matSortActive", "matSortStart", "matSortDirection", "matSortDisableClear", "matSortDisabled"], outputs: ["matSortChange"], exportAs: ["matSort"] }, { kind: "component", type: MatSortHeader, selector: "[mat-sort-header]", inputs: ["mat-sort-header", "arrowPosition", "start", "disabled", "sortActionDescription", "disableClear"], exportAs: ["matSortHeader"] }, { kind: "component", type: MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { kind: "directive", type: MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-table', standalone: true, imports: [
                        DatePipe,
                        DecimalPipe,
                        FormsModule,
                        MatButton,
                        MatCell,
                        MatCellDef,
                        MatCheckbox,
                        MatColumnDef,
                        MatFormField,
                        MatHeaderCell,
                        MatHeaderCellDef,
                        MatHeaderRow,
                        MatHeaderRowDef,
                        MatIcon,
                        MatIconButton,
                        MatInput,
                        MatLabel,
                        MatNoDataRow,
                        MatPaginator,
                        MatPrefix,
                        MatRow,
                        MatRowDef,
                        MatSort,
                        MatSortHeader,
                        MatTable,
                        MatTooltip,
                        NgClass,
                        NgStyle,
                    ], template: "<h3>{{title()}}</h3>\r\n\r\n@if (showSearch()) {\r\n  <mat-form-field appearance=\"outline\">\r\n      <mat-label>Search</mat-label>\r\n      <mat-icon matPrefix>search</mat-icon>\r\n      <input type=\"text\" matInput (keyup)=\"searchFilterChange($event)\">\r\n  </mat-form-field>\r\n}\r\n\r\n<div class=\"table-container\" [ngStyle]=\"{'max-height': maxTableHeight()}\" [class.shrink-table]=\"shrinkTable()\">\r\n    <table mat-table [dataSource]=\"dataSource\" matSort>\r\n      @for (column of columns(); track column) {\r\n        <ng-container [matColumnDef]=\"column.field\">\r\n          <th mat-header-cell *matHeaderCellDef mat-sort-header [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n            <div>{{ column.fieldColumnTitle }}</div>\r\n          </th>\r\n  \r\n          <td mat-cell *matCellDef=\"let data\" [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n            @if(column.isDate) {\r\n              {{ data[column.field] | date:'shortDate' }}\r\n            } @else if (column.isNumber) {\r\n              @if (column.isNumber.needsRounded) {\r\n                @if (column.isNumber.percentage) {\r\n                  {{ data[column.field] | number:'0.0-0' }}%\r\n                } @else {\r\n                  {{ data[column.field] | number:'0.0-0' }}\r\n                }\r\n              } @else {\r\n                @if (column.isNumber.percentage) {\r\n                  {{ data[column.field] | number:'.1-2' }}%\r\n                } @else {\r\n                  {{ data[column.field] | number:'.1-2' }}\r\n                }\r\n              }\r\n            } @else if (column.isCheckbox) {\r\n              <mat-checkbox [(ngModel)]=\"data[column.field]\" [disabled]=\"column.isCheckbox['isDisabled']\" />\r\n            } @else if (column.isHyperlink) {\r\n              <a [href]=\"data[column.isHyperlink.linkField]\" target=\"_blank\">\r\n                {{ data[column.field] }}\r\n              </a>\r\n            } @else if (column.isButton) {\r\n              @if (column.isButton.isIcon) {\r\n                <button mat-icon-button [matTooltip]=\"column.isButton.isIcon.toolTip\" [disabled]=\"column.isButton.isDisabled\"\r\n                  (click)=\"column.isButton.isDisabled ? undefined : buttonClick(data, column.field)\">\r\n                  <mat-icon>{{column.isButton.isIcon.iconName}}</mat-icon>\r\n                </button>\r\n              } @else if (column.isButton.isCheckbox) {\r\n                <mat-checkbox [matTooltip]=\"column.isButton.isCheckbox.toolTip\"\r\n                  [(ngModel)]=\"data[column.field]\" (click)=\"buttonClick(data, column.field)\" />\r\n              } @else {\r\n                <button mat-raised-button [disabled]=\"column.isButton.isDisabled\"\r\n                  [color]=\"column.isButton.isDisabled ? undefined : 'primary'\"\r\n                  [class.button-extra-padding]=\"column.isButton.extraPadding\"\r\n                  (click)=\"column.isButton.isDisabled ? undefined : buttonClick(data, column.field)\">\r\n                  {{column.isButton.text}}\r\n                </button>\r\n              }\r\n            } @else if (column.nestedField) {\r\n              {{ getNestedFieldValue(data[column.field], column.nestedField) }}\r\n            } @else if (column.isEditable) {\r\n                @if (column.isEditable.type === 'textarea') {\r\n                  <textarea style=\"width: 100%;\" [rows]=\"3\" [(ngModel)]=\"data[column.field]\" [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\"></textarea>\r\n                } @else {\r\n                  <input [(ngModel)]=\"data[column.field]\" style=\"width: 55%;\"  [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\" [type]=\"column.isEditable.isNumber ? 'number' : 'text'\">\r\n                }\r\n            } @else {\r\n                {{ data[column.field] }}\r\n            }\r\n          </td>\r\n        </ng-container>\r\n      }\r\n\r\n      <tr mat-header-row *matHeaderRowDef=\"columnNames; sticky: true\"></tr>\r\n      <tr mat-row *matRowDef=\"let row; columns: columnNames;\" class=\"table-row\"></tr>\r\n      <tr mat-row *matNoDataRow>\r\n        <td class=\"mat-cell\" colspan=\"9999\">\r\n          No records exist.\r\n        </td>\r\n      </tr>\r\n    </table>\r\n\r\n    @if (showPaginator()) {\r\n      <mat-paginator [class.paginator-sticky]=\"paginatorSticky()\" [pageSizeOptions]=\"pageSizeOptions\" showFirstLastButtons />\r\n    }\r\n</div>\r\n", styles: [".mat-form-field{width:100%!important}.table-container{display:grid;grid-template-columns:1fr;max-height:50em;overflow:auto;margin:1em .5em .5em;text-align:center!important}.table-container .table{width:100%}:host ::ng-deep .mat-sort-header-container{display:flex;justify-content:center}td,th{text-align:center!important}.shrink-table .mat-mdc-unelevated-button{line-height:1.75em}.shrink-table .mat-mdc-outlined-button{line-height:1.5em;height:1.5em}.shrink-table .mat-mdc-row:hover{background-color:#8f8f8f18;font-weight:700}.shrink-table .mat-mdc-row,tr.mat-row{min-height:1.5em;height:1.5em}.shrink-table .mat-mdc-header-row{min-height:40px}.shrink-table tr.mat-mdc-header-row{height:1.5em;border-radius:5px}.shrink-table .mat-column-tools{min-width:225px;max-width:225px}.shrink-table .mat-mdc-header-cell{font-weight:700}.paginator-sticky{bottom:0;position:sticky;z-index:10}.button-extra-padding{padding-top:1.75em;padding-bottom:1.75em}\n"] }]
        }] });

class TableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: TableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: TableModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatFormFieldModule,
            MatInputModule,
            MatTableModule,
            MatSortModule,
            MatPaginatorModule,
            MatTooltipModule,
            MatIconModule,
            TableComponent], exports: [TableComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: TableModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatFormFieldModule,
            MatInputModule,
            MatTableModule,
            MatSortModule,
            MatPaginatorModule,
            MatTooltipModule,
            MatIconModule,
            TableComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: TableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatTableModule,
                        MatSortModule,
                        MatPaginatorModule,
                        MatTooltipModule,
                        MatIconModule,
                        TableComponent
                    ],
                    exports: [
                        TableComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TableComponent, TableModule };
//# sourceMappingURL=cleavelandprice-ngx-lib-table.mjs.map
