import * as i0 from '@angular/core';
import { InjectionToken, inject, Injectable, Optional, Inject, viewChild, Component, output, NgModule, SkipSelf } from '@angular/core';
import { AsyncPipe, CommonModule } from '@angular/common';
import { MatButton, MatButtonModule } from '@angular/material/button';
import { MatDialogRef, MatDialogActions, MatDialogClose, MatDialogContent, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { MatList, MatListItem, MatListModule } from '@angular/material/list';
import { MatProgressBar, MatProgressBarModule } from '@angular/material/progress-bar';
import { Subject, forkJoin } from 'rxjs';
import { HttpClient, HttpHeaders, HttpRequest, HttpEventType, HttpResponse } from '@angular/common/http';
import { NgxLibServiceBase } from '@cleavelandprice/ngx-lib';

;

const UploadServiceOptionsToken = new InjectionToken('');

// https://malcoded.com/posts/angular-file-upload-component-with-express
class UploadService extends NgxLibServiceBase {
    #http = inject(HttpClient);
    constructor(options) {
        super(options);
        this.options = options;
        this.options = {
            ...options,
            databaseEndpoint: options?.databaseEndpoint ?? '/upload/database',
            uploadDialogTitle: options?.uploadDialogTitle ?? 'Upload Files',
            uploadButtonText: options?.uploadButtonText ?? 'Upload',
            uploadDialogCancelButtonText: options?.uploadDialogCancelButtonText ?? 'Cancel',
            uploadDialogFinishButtonText: options?.uploadDialogFinishButtonText ?? 'Finish',
            uploadDialogUploadButtonText: options?.uploadButtonText ?? 'Upload',
            uploadDialogAddFilesButtonText: options?.uploadDialogAddFilesButtonText ?? 'Add Files'
        };
    }
    upload(files) {
        // this will be the our resulting map
        const status = {};
        files.forEach(file => {
            // create a new multipart-form for every file
            const formData = new FormData();
            formData.append('file', file, file.name);
            // create a http-post request and pass the form
            // tell it to report the upload progress
            // A 'Destination' header is used to optionally configure the file upload destination (filesystem)
            // A 'DbAppId' header is used to configure the unique identifier of database uploads
            let headers = new HttpHeaders();
            if (this.options.uploadPath) {
                headers = headers.set('Destination', this.options.uploadPath);
            }
            if (this.options.dbAppId) {
                headers = headers.set('DbAppId', this.options.dbAppId);
            }
            if (this.options.externalReferenceId) {
                headers = headers.set('ExternalReferenceId', this.options.externalReferenceId);
            }
            if (this.options.comment) {
                headers = headers.set('Comment', this.options.comment);
            }
            const req = new HttpRequest('POST', `${this.apiUrl}${this.options.databaseEndpoint}`, formData, {
                reportProgress: true,
                responseType: 'blob',
                headers
            });
            // create a new progress-subject for every file
            const progress = new Subject();
            // send the http-request and subscribe for progress-updates
            this.#http.request(req).subscribe(event => {
                if (event.type === HttpEventType.UploadProgress) {
                    // calculate the progress percentage
                    const percentDone = Math.round(100 * event.loaded / (event.total ?? 1));
                    // pass the percentage into the progress-stream
                    progress.next(percentDone);
                }
                else if (event instanceof HttpResponse) {
                    // Close the progress-stream if we get an answer form the API
                    // The upload is complete
                    progress.complete();
                }
            });
            // Save every progress-observable in a map of all observables
            status[file.name] = {
                progress: progress.asObservable()
            };
        });
        // return the map of progress.observables
        return status;
    }
    exists(fileName) {
        const query = `${this.apiUrl}${this.options.databaseEndpoint}`.toLowerCase().includes('filesystem') ?
            { name: fileName, destination: this.options.uploadPath } :
            { name: fileName, dbAppId: this.options.dbAppId };
        return this.#http.post(`${this.apiUrl}${this.options.databaseEndpoint}/exists`, query);
    }
    download(request) {
        return this.#http.post(`${this.apiUrl}${this.options.databaseEndpoint}/stream`, request, { responseType: 'blob' });
    }
    getUploadInfo(request) {
        return this.#http.post(`${this.apiUrl}${this.options.databaseEndpoint}/info`, request);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadService, deps: [{ token: UploadServiceOptionsToken, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [UploadServiceOptionsToken]
                }] }] });

class UploadDialogComponent {
    constructor() {
        this.services = {
            dialogRef: inject((MatDialogRef)),
            upload: inject(UploadService)
        };
        this.file = viewChild.required('file');
        this.files = new Set();
        this.canBeClosed = true;
        this.primaryButtonText = this.services.upload.options.uploadDialogUploadButtonText;
        this.showCancelButton = true;
        this.uploading = false;
        this.uploadSuccessful = false;
    }
    addFiles() {
        this.file().nativeElement.click();
    }
    onFilesAdded() {
        const files = this.file().nativeElement.files;
        for (const key in files) {
            if (!isNaN(parseInt(key))) {
                // See if the file already exists
                this.services.upload.exists(files[key].name)
                    .subscribe(exists => {
                    if (exists) {
                        this.existingFileConflict = files[key].name;
                    }
                    if (!exists) {
                        this.files.add(files[key]);
                    }
                });
            }
        }
    }
    closeDialog() {
        // if everything was uploaded already, just close the dialog
        if (this.uploadSuccessful) {
            return this.services.dialogRef.close();
        }
        // set the component state to "uploading"
        this.uploading = true;
        // start the upload and save the progress map
        this.progress = this.services.upload.upload(this.files);
        // convert the progress map into an array
        const allProgressObservables$ = [];
        for (let key in this.progress) {
            allProgressObservables$.push(this.progress[key].progress);
        }
        // Adjust the state variables
        // The OK-button should have the text "Finish" now
        this.primaryButtonText = this.services.upload.options.uploadDialogFinishButtonText;
        // The dialog should not be closed while uploading
        this.canBeClosed = false;
        this.services.dialogRef.disableClose = true;
        // Hide the cancel-button
        this.showCancelButton = false;
        // When all progress-observables are completed...
        forkJoin(allProgressObservables$)
            .subscribe({
            complete: () => {
                // ... the dialog can be closed again...
                this.canBeClosed = true;
                this.services.dialogRef.disableClose = false;
                // ... the upload was successful...
                this.uploadSuccessful = true;
                // ... and the component is no longer uploading
                this.uploading = false;
                console.log('Upload complete', this.files);
                this.services.dialogRef.close();
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadDialogComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.5", type: UploadDialogComponent, isStandalone: true, selector: "ng-component", viewQueries: [{ propertyName: "file", first: true, predicate: ["file"], descendants: true, isSignal: true }], ngImport: i0, template: "<input type=\"file\" #file style=\"display: none\" (change)=\"onFilesAdded()\" multiple />\n\n<div mat-dialog-title id=\"title\">\n  <div>{{ services.upload.options.uploadDialogTitle }}</div>\n  <button [disabled]=\"uploading || uploadSuccessful\" mat-raised-button color=\"primary\" class=\"add-files-btn\" (click)=\"addFiles()\">\n    {{ services.upload.options.uploadDialogAddFilesButtonText }}\n  </button>\n</div>\n\n@if (existingFileConflict) {\n  <div id=\"conflict\">\n    {{ existingFileConflict }} already exists on the server and cannot be overwritten\n  </div>\n}\n\n<mat-dialog-content>\n  <mat-list>\n    @for (file of files; track file) {\n      <mat-list-item>\n        <h4 mat-line>{{file.name}}</h4>\n        @if (progress) {\n          <mat-progress-bar mode=\"determinate\" [value]=\"progress[file.name].progress | async\"/>\n        }\n      </mat-list-item>\n    }\n  </mat-list>\n</mat-dialog-content>\n\n<mat-dialog-actions id=\"actions\">\n  @if (showCancelButton) {\n    <button mat-button mat-dialog-close>{{ services.upload.options.uploadDialogCancelButtonText }}</button>\n  }\n  @if (files.size > 0) {\n    <button mat-raised-button color=\"primary\" [disabled]=\"!canBeClosed\" (click)=\"closeDialog()\">{{ primaryButtonText }}</button>\n  }\n</mat-dialog-actions>\n", styles: ["#title{display:flex;justify-content:space-between}#actions{display:flex;justify-content:flex-end}#conflict{font-size:.8em;color:red;margin-top:.5em}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: MatList, selector: "mat-list", exportAs: ["matList"] }, { kind: "component", type: MatListItem, selector: "mat-list-item, a[mat-list-item], button[mat-list-item]", inputs: ["activated"], exportAs: ["matListItem"] }, { kind: "component", type: MatProgressBar, selector: "mat-progress-bar", inputs: ["color", "value", "bufferValue", "mode"], outputs: ["animationEnd"], exportAs: ["matProgressBar"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadDialogComponent, decorators: [{
            type: Component,
            args: [{ standalone: true, imports: [
                        AsyncPipe,
                        MatButton,
                        MatDialogActions,
                        MatDialogClose,
                        MatDialogContent,
                        MatList,
                        MatListItem,
                        MatProgressBar
                    ], template: "<input type=\"file\" #file style=\"display: none\" (change)=\"onFilesAdded()\" multiple />\n\n<div mat-dialog-title id=\"title\">\n  <div>{{ services.upload.options.uploadDialogTitle }}</div>\n  <button [disabled]=\"uploading || uploadSuccessful\" mat-raised-button color=\"primary\" class=\"add-files-btn\" (click)=\"addFiles()\">\n    {{ services.upload.options.uploadDialogAddFilesButtonText }}\n  </button>\n</div>\n\n@if (existingFileConflict) {\n  <div id=\"conflict\">\n    {{ existingFileConflict }} already exists on the server and cannot be overwritten\n  </div>\n}\n\n<mat-dialog-content>\n  <mat-list>\n    @for (file of files; track file) {\n      <mat-list-item>\n        <h4 mat-line>{{file.name}}</h4>\n        @if (progress) {\n          <mat-progress-bar mode=\"determinate\" [value]=\"progress[file.name].progress | async\"/>\n        }\n      </mat-list-item>\n    }\n  </mat-list>\n</mat-dialog-content>\n\n<mat-dialog-actions id=\"actions\">\n  @if (showCancelButton) {\n    <button mat-button mat-dialog-close>{{ services.upload.options.uploadDialogCancelButtonText }}</button>\n  }\n  @if (files.size > 0) {\n    <button mat-raised-button color=\"primary\" [disabled]=\"!canBeClosed\" (click)=\"closeDialog()\">{{ primaryButtonText }}</button>\n  }\n</mat-dialog-actions>\n", styles: ["#title{display:flex;justify-content:space-between}#actions{display:flex;justify-content:flex-end}#conflict{font-size:.8em;color:red;margin-top:.5em}\n"] }]
        }] });

class UploadComponent {
    constructor() {
        this.#dialogService = inject(MatDialog);
        this.uploadService = inject(UploadService);
        this.dialogClosed = output();
    }
    #dialogService;
    openUploadDialog() {
        this.#dialogService.open(UploadDialogComponent, { width: '50%' })
            .afterClosed().subscribe(() => this.dialogClosed.emit());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.5", type: UploadComponent, isStandalone: true, selector: "cp-upload", outputs: { dialogClosed: "dialogClosed" }, ngImport: i0, template: '<button mat-raised-button (click)="openUploadDialog()">{{ uploadService.options.uploadButtonText }}</button>', isInline: true, dependencies: [{ kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'cp-upload',
                    standalone: true,
                    imports: [
                        MatButton
                    ],
                    template: '<button mat-raised-button (click)="openUploadDialog()">{{ uploadService.options.uploadButtonText }}</button>'
                }]
        }] });

class UploadModule {
    static forRoot(options) {
        return {
            ngModule: UploadModule,
            providers: [
                {
                    provide: UploadServiceOptionsToken,
                    useValue: options
                }
            ]
        };
    }
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('UploadModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadModule, deps: [{ token: UploadModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: UploadModule, imports: [CommonModule,
            MatButtonModule,
            MatDialogModule,
            MatListModule,
            MatProgressBarModule,
            UploadComponent,
            UploadDialogComponent], exports: [UploadComponent,
            UploadDialogComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadModule, imports: [CommonModule,
            MatButtonModule,
            MatDialogModule,
            MatListModule,
            MatProgressBarModule,
            UploadComponent,
            UploadDialogComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UploadModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatListModule,
                        MatProgressBarModule,
                        UploadComponent,
                        UploadDialogComponent
                    ],
                    exports: [
                        UploadComponent,
                        UploadDialogComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: UploadModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { UploadComponent, UploadDialogComponent, UploadModule, UploadService, UploadServiceOptionsToken };
//# sourceMappingURL=cleavelandprice-ngx-lib-upload.mjs.map
