import * as i0 from '@angular/core';
import { inject, Pipe, NgModule } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';

class SafeResourceUrlPipe {
    #domSanitizer = inject(DomSanitizer);
    transform(value) {
        return this.#domSanitizer.bypassSecurityTrustResourceUrl(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SafeResourceUrlPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: SafeResourceUrlPipe, isStandalone: true, name: "safeResourceUrl" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SafeResourceUrlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safeResourceUrl',
                    standalone: true
                }]
        }] });

class SafeUrlPipe {
    #domSanitizer = inject(DomSanitizer);
    transform(value) {
        return this.#domSanitizer.bypassSecurityTrustUrl(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SafeUrlPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: SafeUrlPipe, isStandalone: true, name: "safeUrl" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: SafeUrlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safeUrl',
                    standalone: true
                }]
        }] });

class UriSchemePipe {
    // https://docs.microsoft.com/en-us/office/client-developer/office-uri-schemes
    transform(value, ignoreLocalStorage = false) {
        if (!localStorage.getItem('useUriScheme') && !ignoreLocalStorage) {
            return value;
        }
        const urlSplit = value.split('.');
        const extension = urlSplit[urlSplit.length - 1];
        if (!extension) {
            return value;
        }
        const command = this.#command(extension);
        const app = this.#app(extension);
        return `ms-${app}:${command}|u|${value}`;
    }
    #app(extension) {
        switch (extension.toLowerCase()) {
            // documents
            case 'doc':
            case 'docx':
            case 'docm':
            case 'docb':
            case 'dot':
            case 'dotx':
            case 'dotm': // templates
                return 'word';
            case 'xls':
            case 'xlsx':
            case 'xlm':
            case 'xlsm':
            case 'xlsb':
            case 'xlw':
            case 'xlt':
            case 'xltx':
            case 'xltm': // templates
                return 'excel';
            case 'ppt':
            case 'pptx':
            case 'pps':
            case 'ppsx':
            case 'pptm':
            case 'ppsm':
            case 'sldx':
            case 'sldm':
            case 'pot':
            case 'potx':
            case 'potm': // templates
                return 'powerpoint';
            case 'vsd':
            case 'vsdx':
            case 'vst':
            case 'vstx': // templates
                return 'visio';
            case 'mdb':
            case 'accdb':
            case 'accde':
            case 'accdr':
            case 'accdt': // templates
                return 'access';
            case 'mpp':
            case 'mppx':
            case 'mpt': // templates
                return 'project';
            case 'pub':
                return 'publisher';
            case 'xsn':
                return 'infopath';
            default:
                return '';
        }
    }
    #command(extension) {
        switch (extension.toLowerCase()) {
            case 'dot':
            case 'dotx':
            case 'dotm':
            case 'xlt':
            case 'xltx':
            case 'xltm':
            case 'pot':
            case 'potx':
            case 'potm':
            case 'vst':
            case 'vstx':
            case 'accdt':
            case 'mpt':
                return 'nft'; // new from template
            default:
                const openMode = 'v'; // for view, or 'e' or edit
                return `of${openMode}`; // default: open file as view/edit
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UriSchemePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: UriSchemePipe, isStandalone: true, name: "uriScheme", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UriSchemePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'uriScheme',
                    standalone: true,
                    pure: false
                }]
        }] });

class UrlUtilitiesModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UrlUtilitiesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: UrlUtilitiesModule, imports: [CommonModule,
            SafeResourceUrlPipe,
            SafeUrlPipe,
            UriSchemePipe], exports: [SafeResourceUrlPipe,
            SafeUrlPipe,
            UriSchemePipe] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UrlUtilitiesModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: UrlUtilitiesModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        SafeResourceUrlPipe,
                        SafeUrlPipe,
                        UriSchemePipe
                    ],
                    exports: [
                        SafeResourceUrlPipe,
                        SafeUrlPipe,
                        UriSchemePipe
                    ]
                }]
        }] });

const CP_URL_PIPES = [
    SafeResourceUrlPipe,
    SafeUrlPipe,
    UriSchemePipe
];

/**
 * Generated bundle index. Do not edit.
 */

export { CP_URL_PIPES, SafeResourceUrlPipe, SafeUrlPipe, UriSchemePipe, UrlUtilitiesModule };
//# sourceMappingURL=cleavelandprice-ngx-lib-url-utilities.mjs.map
